/* Copyright (c) 2013, 2014, Oracle and/or its affiliates. 
All rights reserved.*/

/*
   DESCRIPTION
    Mapper class for demo 

   VERSION
    1.0.1
 */

package oracle.oc4hadoop.demo;

import java.util.regex.Pattern;
import org.apache.hadoop.io.LongWritable;
import org.apache.hadoop.io.NullWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Mapper;

public final class CSVToArrayMapper extends
        Mapper<LongWritable, Text, NullWritable, DoubleArrayWritable> {
    private static final Pattern CSV_SEPARATOR = Pattern.compile("[,;]");
    private double[] dataRow;

    @Override
    public void map(LongWritable key, Text value,
            Mapper<LongWritable, Text, NullWritable, DoubleArrayWritable>.Context context)
            throws java.io.IOException, InterruptedException {

        final String[] tokens = CSV_SEPARATOR.split(value.toString(), -1);
        final int nTokens = tokens.length;

        if (dataRow == null) {
            dataRow = new double[nTokens];
        }

        if (dataRow.length != nTokens) {
            throw new RuntimeException("CSV error: inconsistent number of tokens");
        }

        try {
            for (int col = 0; col < nTokens; col++) {
                dataRow[col] = Double.parseDouble(tokens[col]);
            }
        } catch (NumberFormatException numberFormatException) {
            return; // Unable to parse the row, skip it.
        }

      context.write(NullWritable.get(), new DoubleArrayWritable(dataRow));
    }
 }
