/* Copyright (c) 2013, 2014, Oracle and/or its affiliates. 
All rights reserved.*/

/*
   DESCRIPTION
    This class create a Custom Writable 

   VERSION
    1.0.1
 */

package oracle.oc4hadoop.demo;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.math.BigDecimal;
import java.sql.SQLData;
import java.sql.SQLException;
import java.sql.SQLInput;
import java.sql.SQLOutput;
import oracle.jdbc.OracleConnection;
import oracle.jdbc.OracleDriver;
import org.apache.hadoop.io.Writable;


public final class DoubleArrayWritable implements Writable, SQLData
{

  public int nElements;
  public double[] data;
  private String sqlTypeName = "ARRAYWRITABLE";

  public DoubleArrayWritable()
  {
  }

  public DoubleArrayWritable(final double[] data)
  {
    this.nElements = data.length;
    this.data = data;
  }

  @Override
  public String getSQLTypeName() throws SQLException
  {
    return sqlTypeName;
  }

  @Override
  public void readSQL(SQLInput stream, String typeName) throws SQLException
  {
    sqlTypeName = typeName;
    Object obarr[] = (Object[]) stream.readArray().getArray();
    data = new double[obarr.length];
    int i = 0;
    for(Object o:obarr)
    {
      data[i] = ((BigDecimal)o).doubleValue();
      i++;
    } 
    this.nElements = stream.readInt();
  }

  @Override
  public void writeSQL(SQLOutput stream) throws SQLException
  {
      OracleDriver ora = new OracleDriver();
      OracleConnection conn = (OracleConnection) ora.defaultConnection();
      stream.writeArray(conn.createARRAY("DOUBLEARRAY", this.data));
      stream.writeInt(this.nElements);
  }

  public static DoubleArrayWritable read(DataInput in) throws IOException
  {
    DoubleArrayWritable writable = new DoubleArrayWritable();
    writable.readFields(in);
    return writable;
  }

  @Override
  public void readFields(DataInput in) throws IOException
  {
    nElements = in.readInt();

    if (data == null) {
      data = new double[nElements];
        }
    
    for (int i = 0; i < nElements; i++) {
      data[i] = in.readDouble();
    }
  }

  @Override
  public void write(DataOutput out) throws IOException
  {
    out.writeInt(nElements);

    for (double d : data) {
        out.writeDouble(d);
      }
    }
  }
