/* Copyright (c) 2013, 2014, Oracle and/or its affiliates. 
All rights reserved.*/

/*
   DESCRIPTION
    The example code for inverted index on text. The input is in the form of
    <LongWritable, Text>. The output is in the form of <Text, TextArrayWritable>.
    Some stop words and irregular ones in the text are ignored. The jobKey()
    method returns a retrieval key for the job configuration object.
  
   VERSION
    1.0.1
 */

package oracle.sql.hadoop.examples;

import oracle.sql.hadoop.Job;
import oracle.sql.hadoop.ConfigManager;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.io.LongWritable;
import org.apache.hadoop.io.Text;

public class InvertedIndexSQL {

    public static long jobKey(String arg) throws Exception {
        // Take the user specified options and pass them to the parser.
        Configuration conf = new Configuration();
        ConfigManager.parse(conf, arg);

        Job job = new Job(conf, "InvertedIndex");
        job.setInputTableName("InTable");
        job.setOutputTableName("OutTable");
        job.setMapperClass(oracle.sql.hadoop.examples.InvertedIndex.InvertedIndexMapper.class);
        job.setReducerClass(oracle.sql.hadoop.examples.InvertedIndex.InvertedIndexReducer.class);
        job.setInputKeyClass(LongWritable.class);
        job.setInputValueClass(Text.class);
        job.setMapOutputKeyClass(Text.class);
        job.setMapOutputValueClass(Text.class);
        job.setOutputKeyClass(Text.class);
        job.setOutputValueClass(oracle.sql.hadoop.examples.InvertedIndex.TextArrayWritable.class);

        job.setMapOutputKeyDBType("VARCHAR2(50)");
        job.setMapOutputValueDBType("VARCHAR2(200)");
        job.setOutputKeyDBType("VARCHAR2(50)");
        job.setOutputValueDBType("ARRAYLIST");


        // Store the job configuration and return the retrieval key.
        return job.init();
    }
}
