Rem Copyright (c) 2013, 2014, Oracle and/or its affiliates. 
Rem All rights reserved.
Rem
Rem    NAME
Rem      InvertedIndexSQL.sql 
Rem
Rem    DESCRIPTION
Rem    Demo script for the inverted index example.
 
Rem    The user calls the Java program to accept configuration,
Rem    and compose the queries with such configuration.

SET ECHO ON
SET FEEDBACK 1
SET NUMWIDTH 10
SET LINESIZE 80
SET TRIMSPOOL ON
SET TAB OFF
SET PAGESIZE 100


drop type ARRAYLIST force;
create type ARRAYLIST as VARRAY(10000000) of VARCHAR2(30);
/

Drop table InTable;
 
-- Create the input table.
CREATE TABLE InTable (
  sayings 	VARCHAR2(1000)
);


-- Populate the input table.
insert into InTable values ('A faith is a necessity to a man. Woe to him who believes in nothing.');
insert into InTable values ('All who call on God in true faith, earnestly from the heart, will certainly be heard, and will receive what they have asked and desired.');
insert into InTable values ('Faith is not contrary to reason.');
insert into InTable values ('I can accept failure, everyone fails at something. But I cannot accept not trying.');
insert into InTable values ('Anyone who does not take truth seriously in small matters cannot be trusted in large ones either.');

select * from InTable;
DROP TABLE OutTable;

-- Call the java program to generate job configuration.
DROP FUNCTION InvertedIndexSQL;
CREATE OR REPLACE FUNCTION InvertedIndexSQL(arg VARCHAR2) RETURN NUMBER
  AS LANGUAGE JAVA
	NAME 'oracle.sql.hadoop.examples.InvertedIndexSQL.jobKey(java.lang.String) return java.math.BigDecimal';
/
variable ConfKey NUMBER;
call InvertedIndexSQL('') INTO :ConfKey;

-- Make the query.
create table OutTable of OUT_HADOOP_INVERTEDINDEX;

SET TIMING ON
insert /*+ enable_parallel_dml */ into OutTable select * from table(HREDUCE_JP_INVERTEDINDEX(:ConfKey, cursor(select /*+ PARALLEL(t2,4) */ * from table(HMAP_JP_INVERTEDINDEX(:ConfKey, cursor(select /*+ PARALLEL(t1,4) */ rowid,  SAYINGS from InTable t1)))t2)));
select * from OutTable order by keyout;
quit;
