/* Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.*/

/*
   DESCRIPTION
    Class for demo
 
   VERSION
    1.0.1
 */

package oracle.sql.hadoop.examples;

import java.io.IOException;
import oracle.sql.hadoop.ConfigManager;
import oracle.sql.hadoop.Job;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.io.IntWritable;
import org.apache.hadoop.io.LongWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Mapper;
import org.apache.hadoop.mapreduce.Reducer;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;

public final class MarketBasket {

  public static class CooccurrenceMapper
    extends Mapper<LongWritable, Text, Text, IntWritable> {

    private static final String ITEM_KEY = "items";
    private static final String INVOICE_KEY = "invoice#";
    private static final IntWritable ONE = new IntWritable(1);
    private Text itemPair = new Text();

    @Override
    public void map(LongWritable rowid, Text value, Context context)
      throws IOException, InterruptedException {
      JSONObject jsonObj = null;
      try {
        jsonObj = new JSONObject(value.toString());
        JSONArray itemList = jsonObj.getJSONArray(ITEM_KEY);
        int itemsOrdered = itemList.length();
        for (int i = 0; i < itemsOrdered - 1; i++) {
          int a = itemList.getInt(i);
          for (int j = i + 1; j < itemsOrdered; j++) {
            int b = itemList.getInt(j);
            if (a < b) {
              itemPair.set(a + ", " + b);
            } else {
              itemPair.set(b + ", " + a);
            }
            context.write(itemPair, ONE);
          }
        }
      } catch (JSONException e) {
        try {
          throw new IOException("Exception while processing invoice#: " +
                  jsonObj.getInt(INVOICE_KEY), e);
        } catch (JSONException je) {
          throw new IOException(je);
        }
      }
    }
  }
  
  public static class IntSumReducer
    extends Reducer<Text, IntWritable, Text, IntWritable> {

    private IntWritable result = new IntWritable();
    
    @Override
    public void reduce(Text key, Iterable<IntWritable> values, Context context)
      throws IOException, InterruptedException {
        int sum = 0;
        for (IntWritable val : values) {
            sum += val.get();
        }
        result.set(sum);
        context.write(key, result);
    }
  }

  public static void run(String args) throws Exception {

    Configuration conf = new Configuration();
    ConfigManager.parse(conf, args);
    Job job = new Job(conf, "MarketBasket");

    job.setMapperClass(CooccurrenceMapper.class);
    job.setReducerClass(IntSumReducer.class);
    job.setOutputKeyClass(Text.class);
    job.setOutputValueClass(IntWritable.class);
    job.setOutputKeyDBType("VARCHAR2(10)");
    job.setOutputValueDBType("NUMBER");
    job.setCreateOutputTable(false);

    job.init();
    job.run("InTable", "OutTable");
  }
}

