/* Copyright (c) 2013, 2014, Oracle and/or its affiliates. 
All rights reserved.*/

/*
   DESCRIPTION
    In DataBase MapReduce code to rate farmers market.

   VERSION
    1.0.1

   CREDITS
    Adapted from Helen Zeng's youtube demo on http://www.youtube.com/watch?v=KwW7bQRykHI
    Code captured by Kuassi Mensah.

 */

package oracle.oc4hadoop.demo;

import java.io.IOException;
import java.net.URL;
import java.util.Iterator;
import oracle.sql.hadoop.ConfigManager;
import oracle.sql.hadoop.Job;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.io.LongWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Mapper;
import org.apache.hadoop.mapreduce.Reducer;
import oracle.aurora.rdbms.Schema;

public class MarketRatings{

  public static class MapClass extends Mapper<LongWritable, Text, Text, Text> {

    private Text loc = new Text();
    private Text rating = new Text();

    @Override
    public void map(LongWritable key, Text value, 
             Context context) throws IOException, InterruptedException {

      String valString = value.toString();
      String[] row = valString.split(",");

      // Insufficient Data to analyze. Return
      if(row.length < 2) 
        return;

      String city = row[0];
      String state = row[1];


      float count=0;
      int rated = 0;
      for(int col=2; col<=26; col++) { 
        //columns 11-31 contains data about what the market offers
        if(row[col].equals("Y"))
        count++;
      }

      count=(count*100)/25; //gets 1-100 ratings of the market

      if(count>0) {
        rated = 1;
      }

      loc.set(city + ", "+ state);
      rating.set(1+"\t"+rated+"\t"+count); //numTotal, numRated, rating
      context.write(loc, rating);

    }
  }

  public static class ReduceClass extends Reducer<Text, Text, Text, Text> {
      
    @Override
    public void reduce(Text key, Iterable<Text> values,
            Context context) throws IOException, InterruptedException {

      float rating = 0;
      int numRated = 0;
      int numTotal = 0;

      Iterator<Text> valIter = values.iterator();

      while (valIter.hasNext()) {
        String tokens[] = (valIter.next().toString()).split("\t");
        int tot = Integer.parseInt(tokens[0]);
        int num = Integer.parseInt(tokens[1]); //gets number of markets
        float val = Float.parseFloat(tokens[2]); //gets rating
        if(val>0)                              //filters out markets with no data
        {
          rating = (rating*numRated + val*num)/(numRated+num);
          numRated = numRated + num;
        }
        numTotal=numTotal+tot;
      }
      if(rating>0)
        context.write(key, new Text(numTotal + "\t" + numRated + "\t" + rating));
    }
  }

  public static void run(String arg, int runForTable) throws Exception {
    // Take the user specified options and pass them to the parser.
    Configuration conf = new Configuration();
    ConfigManager.parse(conf, arg);
    // Reading Configuration from a resource file loaded in the current schema
    if(runForTable != 0) {
      conf.addResource(new URL("jserver:/resource/schema/" + 
                Schema.currentSchema() + "/MarketRatingsTableConf.xml"));
    }
    else {
      conf.addResource(new URL("jserver:/resource/schema/" + 
                Schema.currentSchema() + "/MarketRatingsHDFSConf.xml"));
    }
    
    // Specify the job parameters.
    Job job = new Job(conf, "MarketRatings");
    job.setMapperClass(MapClass.class);
    job.setReducerClass(ReduceClass.class);
    
    job.init();
    job.run();
  }
  
}
