Rem Copyright (c) 2011, 2014, Oracle and/or its affiliates. 
Rem All rights reserved.
Rem
Rem    NAME
Rem     RandTextWordCount.sql 
Rem
Rem    DESCRIPTION
Rem     Generate random text by pulling random words from a dictionary
Rem     and run word count on it.


-- Get the parameters.
prompt;
prompt Please specify the number of rows to write.
accept num_row DEFAULT 10000 prompt 'NUMBER (10000 by default): ';
prompt;

-- Create the table;
prompt ========================================================================;
prompt Creating the input table...;
prompt ========================================================================;
DROP TABLE InTable;
CREATE TABLE InTable (
  key		VARCHAR2(100),
  value		VARCHAR2(300)
);

-- Populate the table;
prompt ========================================================================;
prompt Writing random text to the input table...;
prompt ========================================================================;
CREATE OR REPLACE PROCEDURE RandomTextWriter(tabl_name VARCHAR2, nrows NUMBER)
  AS LANGUAGE JAVA
  NAME 'oracle.sql.hadoop.examples.RandomTextWriter.run(java.lang.String, java.math.BigDecimal)';
/
call RandomTextWriter('InTable', &num_row);

prompt Finished writing random text to InTable.
prompt;


prompt ========================================================================;
prompt Preparing for running word count...
prompt ========================================================================;
prompt;

-- Call the java program to generate job configuration.
DROP FUNCTION WordCountConf;
CREATE OR REPLACE FUNCTION WordCountSQL(arg VARCHAR2) RETURN NUMBER
  AS LANGUAGE JAVA
	NAME 'oracle.sql.hadoop.examples.WordCountSQL.jobKey(java.lang.String) return java.math.BigDecimal';
/
variable ConfKey NUMBER;
call WordCountSQL('') INTO :ConfKey;
DROP TABLE OutTable;
create table OutTable of OUT_HADOOP_WORDCOUNT;

prompt ========================================================================;
prompt Running Word Count...
prompt ========================================================================;
prompt;

SET TIMING ON
insert /*+ enable_parallel_dml */ into OutTable select * from table
  (HREDUCE_JP_WORDCOUNT(:ConfKey, cursor(select * /*+ PARALLEL(t2, 1) */ from table
    (HMAP_JP_WORDCOUNT(:ConfKey, cursor(select /*+ PARALLEL(t1, 1) */ * from InTable t1))) t2)));

prompt ========================================================================;
prompt The output has been written to OutTable.
prompt ========================================================================;
prompt;
quit;
