/* Copyright (c) 2011, 2014, Oracle and/or its affiliates. 
All rights reserved.*/

/*
   DESCRIPTION
    This demo counts the frequency of words. 

   VERSION
    1.0.1
 */

package oracle.sql.hadoop.examples;

import oracle.sql.hadoop.ConfigManager;
import oracle.sql.hadoop.Job;

import org.apache.hadoop.io.Text;
import org.apache.hadoop.io.IntWritable;
import org.apache.hadoop.conf.Configuration;
import java.io.IOException;
import java.util.StringTokenizer;
import org.apache.hadoop.mapreduce.Mapper;
import org.apache.hadoop.mapreduce.Reducer;

public class WordCount {

    public static class TokenizerMapper
      extends Mapper<Text, Text, Text, IntWritable> {

      private final static IntWritable one = new IntWritable(1);
      private Text word = new Text();

      public void map(Text key, Text value, Context context) 
        throws IOException, InterruptedException {
        StringTokenizer itr = new StringTokenizer(value.toString());
        while (itr.hasMoreTokens()) {
          word.set(itr.nextToken());
          context.write(word, one);
        }
      }
    }

    public static class IntSumReducer
      extends Reducer<Text, IntWritable, Text, IntWritable> {

      private IntWritable result = new IntWritable();

      public void reduce(Text key, Iterable<IntWritable> values,
        Context context) throws IOException, InterruptedException {
        int sum = 0;
        for (IntWritable val : values) {
          sum += val.get();
        }
        result.set(sum);
        context.write(key, result);
      }
    }

    public static void run(String arg) throws Exception {
      // Take the user specified options and pass them to the parser.
      Configuration conf = new Configuration();
      ConfigManager.parse(conf, arg);

      // Specify the job parameters.
      Job job = new Job(conf, "WordCount");
      job.setMapperClass(oracle.sql.hadoop.examples.WordCount.TokenizerMapper.class);
      job.setReducerClass(oracle.sql.hadoop.examples.WordCount.IntSumReducer.class);
      job.setInputKeyClass(Text.class);
      job.setInputValueClass(Text.class);
      job.setOutputKeyClass(Text.class);
      job.setOutputValueClass(IntWritable.class);

      // Set the output DB types.
      job.setOutputKeyDBType("VARCHAR2(100)");
      job.setOutputValueDBType("NUMBER");

      job.setNumMapTasks(2);
      job.setNumReduceTasks(2);

      job.init();
      job.run("InTable", "OutTable");
    }
}
