/* Copyright (c) 2011, 2014, Oracle and/or its affiliates. 
All rights reserved.*/
                                           
/*                                                  
   DESCRIPTION 
    This demo class written in scala counts the frequency of words. 
                              
   VERSION             
    1.0.1                                                           
 */

import oracle.sql.hadoop.Job
import org.apache.hadoop.io.{Text, IntWritable}
import org.apache.hadoop.conf.Configuration
import org.apache.hadoop.mapreduce.{Mapper, Reducer}

class WordCountMapper extends Mapper[Text, Text, Text, IntWritable]{
  val one = new IntWritable(1)
  val word = new Text()
  type MapperContext = Mapper[Text, Text, Text, IntWritable]#Context
  
  override def map(key: Text, value: Text, context: MapperContext): Unit = {
    var line = value.toString()
    line.split(" ").foreach(a => {word.set(a);context.write(word, one);})
  }
}

class WordCountReducer extends Reducer[Text, IntWritable, Text, IntWritable] {
  type ReducerContext = Reducer[Text, IntWritable, Text, IntWritable]#Context
  
  override def reduce(key: Text, values: java.lang.Iterable[IntWritable], context: ReducerContext): Unit = {
    var sum = 0;
    val it = values.iterator
    while(it.hasNext) {
      sum += it.next.get
    }
    context.write(key, new IntWritable(sum))
  }
}

object WordCount {
  
  def run() : Unit = {
    val conf = new Configuration
    val job = new Job(conf, "WordCountScala")
    job.setMapperClass(classOf[WordCountMapper])
    job.setReducerClass(classOf[WordCountReducer])
    job.setInputKeyClass(classOf[Text])
    job.setInputValueClass(classOf[Text])
    job.setOutputKeyClass(classOf[Text])
    job.setOutputValueClass(classOf[IntWritable])
    // Set the output DB types.
    job.setOutputKeyDBType("VARCHAR2(10)")
    job.setOutputValueDBType("NUMBER")

    job.init()
    job.run("InTable", "OutTable")

  }
}
