#!/usr/local/bin/perl
# Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
# 
#   NAME
#     load_oc4hadoop.pl
# 
#   DESCRIPTION
#     Loads oc4hadoop jars using loadjava tool. This allows jar files to be
#     loaded from a remote client's filesystem.
# 
#   VERSION
#    1.0.1
#

use Getopt::Long;
use Term::ReadKey;

my $verbose          = '';
my $force            = '';
my $debug            = '';
my $password         = '';
my $connectionString = '';

GetOptions ("connection:s" => \$connectionString,
            "help"         => \$help,
            "password=s"   => \$password,           
            "force"        => \$force,
            "debug"        => \$debug,
            "verbose"      => \$verbose)  or print_usage();

if ( $help ) {
  print_usage();
}

if ( !$password ) {
  print "Password for OC4H_INSTALL schema is not provided !!\n";
  print "Enter password for OC4H_INSTALL:\n";
  ReadMode('noecho');
  $password = <STDIN>;
  chomp($password);
  ReadMode(0);
}

$install_schema = "OC4H_INSTALL";

if ( $verbose ) {
  if ( $force ) {
    system("perl perl/load_file.pl -f -v -t -j lib/base_hadoop.jar -p $password -c $connectionString"); 
    if ( $debug ) {
      system("perl perl/load_file.pl -f -v -t -j lib/oc4hadoop_g.jar -p $password -c $connectionString"); 
    } else {
      system("perl perl/load_file.pl -f -v -t -j lib/oc4hadoop.jar -p $password -c $connectionString"); 
    }
  } else {
    system("perl perl/load_file.pl -v -t -j lib/base_hadoop.jar -p $password -c $connectionString"); 
    if ( $debug ) {
      system("perl perl/load_file.pl -v -t -j lib/oc4hadoop_g.jar -p $password -c $connectionString"); 
    } else {
      system("perl perl/load_file.pl -v -t -j lib/oc4hadoop.jar -p $password -c $connectionString"); 
    }
  }
  print "Done Installing OC4HADOOP !!\n"
} else {
  if ( $force ) {
    system("perl perl/load_file.pl -f -t -j lib/base_hadoop.jar -p $password -c $connectionString");
    if ( $debug ) {
      system("perl perl/load_file.pl -f -t -j lib/oc4hadoop_g.jar -p $password -c $connectionString");
    } else {
      system("perl perl/load_file.pl -f -t -j lib/oc4hadoop.jar -p $password -c $connectionString");
    }
  } else {
    system("perl perl/load_file.pl -t -j lib/base_hadoop.jar -p $password -c $connectionString");
    if ( $debug ) {
      system("perl perl/load_file.pl -t -j lib/oc4hadoop_g.jar -p $password -c $connectionString");
    } else {
      system("perl perl/load_file.pl -t -j lib/oc4hadoop.jar -p $password -c $connectionString");
    }
  }
  print "Done Installing OC4HADOOP !!\n"
}
sub print_usage() {
  print "Usage  : \n \t install_oc4hadoop [Options] \n";
  print "Options: \n \t -c,  -connection : Database URL. The format is host:lport/SID. e.g (localhost:5521/orcl).
                  \n \t -f,  --force     : Load with force.
                  \n \t -d,  --debug     : Load debug jar i.e. oc4hadoop_g.jar.
                  \n \t -h,  --help      : Print Usage.
                  \n \t -p,  --password  : Password of OC4H_ISNTALL schema. 
                  \n \t -v,  --verbose   : To use verbose option.\n";
  exit;
}
