#!/usr/local/bin/perl
# Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
#
#    NAME
#      drop_jar.pl
#
#    DESCRIPTION
#     Drops jar related to oc4hadoop installed on remote machine.
#
#    VERSION
#     1.0.1
# 

use Getopt::Long;
use Env qw($TWO_TASK);

my $jarname  = '';
my $verbose  = '';
my $password = '';
my $connectionString = '';

GetOptions ("connection:s" => \$connectionString,
            "help"         => \$help,
            "jarname=s"    => \$jarname,
      	    "password=s"   => \$password,
            "thin"         => \$thin,
            "verbose"      => \$verbose)  or print_usage();

if ( $help ) { 
  print_usage();
}

if ( !$password ) {
  print "Password for OC4H_INSTALL schema is not provided !!\n";
  print_usage();
}

if ( !$connectionString ) {  $connectionString = $TWO_TASK;  }

if ( !$connectionString ) {
  print "Please provide connection String with -c option or \nSet TWO_TASK environment variable\n";
  die;
  print_usage();
}

if ( -e $jarname ) {
  print "Dropping $jarname \n";
  if( $thin ) {
    if ( $verbose ) {
      system("dropjava -t -v -u oc4h_install/$password\@$connectionString -synonym $jarname");
    } else {
      system("dropjava -t -u oc4h_install/$password\@$connectionString -synonym $jarname");
    }
  }
  else {
    if ( $verbose ) {
      system("dropjava -v -u oc4h_install/$password\@$connectionString -synonym $jarname");
    } else {
      system("dropjava -u oc4h_install/$password\@$connectionString -synonym $jarname");
    }
  }
}
else {
  print "File: $jarname Doesn't Exist!\n";
  print_usage();
}

sub print_usage() {
  print "Usage  : \n \t drop_file [Options] \n";
  print "Options: \n \t -c,  --connection : Database URL. The format is host:lport/SID. e.g (localhost:5521/orcl).
                  \n \t -h,  --help       : Print Usage.
                  \n \t -j,  --jarname    : File to be loaded.
                  \n \t -p,  --password   : Password of OC4H_ISNTALL schema.
                  \n \t -t,  --thin       : To use JDBC Thin driver.
                  \n \t -v,  --verbose    : To print verbose\n";
  exit;
}
