#!/usr/local/bin/perl
# Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
#
#    NAME
#      load_jar.pl
#
#    DESCRIPTION
#     Loads jar related to oc4hadoop installed on remote machine.
#
#    VERSION
#     1.0.1
# 

use Getopt::Long;
use Env qw($TWO_TASK);

my $jarname          = '';
my $force            = '';
my $verbose          = '';
my $thin             = '';
my $password         = '';
my $connectionString = '';

GetOptions ("connection:s" => \$connectionString,
            "jarname=s"    => \$jarname,
            "help"         => \$help,
            "password=s"   => \$password,
            "force"        => \$force,
            "thin"         => \$thin,
            "verbose"      => \$verbose)  or print_usage();

if( $help ) {
  print_usage();
}

if ( !$password ) { 
  print "Password for OC4H_INSTALL schema is not provided !!\n";
  print_usage();
}

if ( !$connectionString ) { $connectionString = $TWO_TASK; }

if ( !$connectionString ) {
  print "Please provide connection String with -c option or \nSet TWO_TASK environment variable\n";
  print_usage();
}

$install_schema = "OC4H_INSTALL";

if ( -e $jarname ) {
  if ( $thin ) {
    if ( $verbose ) {
      if ( $force ) {
        print "Loading $jarname \n";
        system("loadjava -noverify -v -thin -u oc4h_install/$password\@$connectionString -force -resolver \"((* $install_schema)(* SYS)(* -))\"  -resolve $jarname");
      } else {
        print "Resolving $jarname \n";
        system("loadjava -noverify -v -thin -u oc4h_install/$password\@$connectionString -resolver \"((* $install_schema)(* SYS)(* -))\"  -resolve $jarname");
      }
    } else {
      if ( $force ) {
        print "Loading $jarname \n";
        system("loadjava -noverify -thin -u oc4h_install/$password\@$connectionString -force -resolver \"((* $install_schema)(* SYS)(* -))\"  -resolve $jarname");
      } else {
        print "Resolving $jarname \n";
        system("loadjava -noverify -thin -u oc4h_install/$password\@$connectionString -resolver \"((* $install_schema)(* SYS)(* -))\"  -resolve $jarname");
      }
    }
  } else {
    if ( $verbose ) {
      if ( $force ) {
        print "Loading $jarname \n";
        system("loadjava -noverify -v -u oc4h_install/$password\@$connectionString -force -resolver \"((* $install_schema)(* SYS)(* -))\"  -resolve $jarname");
      } else {
        print "Resolving $jarname \n";
        system("loadjava -noverify -v -u oc4h_install/$password\@$connectionString -resolver \"((* $install_schema)(* SYS)(* -))\"  -resolve $jarname");
      }
    } else {
      if ( $force ) {
        print "Loading $jarname \n";
        system("loadjava -noverify -u oc4h_install/$password\@$connectionString -force -resolver \"((* $install_schema)(* SYS)(* -))\"  -resolve $jarname");
      } else {
        print "Resolving $jarname \n";
        system("loadjava -noverify -u oc4h_install/$password\@$connectionString -resolver \"((* $install_schema)(* SYS)(* -))\"  -resolve $jarname");
      }
    }
  }
} else {
  print "File: $jarname Doesn't Exist! \n";
  print_usage();
}

sub print_usage() {
  print "Usage  : \n \t load_file [Options]\n";
  print "Options: \n \t -c,  --connection : Database URL. The format is host:lport/SID. e.g (localhost:5521/orcl).
                  \n \t -f,  --force      : Load with force.
                  \n \t -h,  --help       : Print Usage.             
                  \n \t -j,  --jarname    : File to be loaded.
                  \n \t -p,  --password   : Password of OC4H_ISNTALL schema. 
   		  \n \t -t,  --thin       : To use JDBC Thin driver.
                  \n \t -v,  --verbose    : Print verbose\n";
die;
  exit 0;
}
